# wmo event types list per Cg-18
WMO_HAZARD_EVENTS_TYPE_CHOICES = (
    ("Avalanche", "Avalanche"),
    ("Cold wave", "Cold wave"),
    ("Drought/Dry spell", "Drought/Dry spell"),
    ("Dust storm/Sandstorm", "Dust storm/Sandstorm"),
    ("Extra-tropical cyclone", "Extra-tropical cyclone"),
    ("Flood", "Flood"),
    ("Fog", "Fog"),
    ("Haze/Smoke", "Haze/Smoke"),
    ("Frost", "Frost"),
    ("Hail", "Hail"),
    ("Heat wave", "Heat wave"),
    ("High UV radiation", "High UV radiation"),
    ("Icing", "Icing"),
    ("Freezing rain", "Freezing rain"),
    ("Landslide/Mudslide & Debris flow", "Landslide/Mudslide & Debris flow"),
    ("Lighting", "Lighting"),
    ("Pollen pollution/Polluted air", "Pollen pollution/Polluted air"),
    ("Rain/Wet Spell", "Rain/Wet Spell"),
    ("Snow", "Snow"),
    ("Snowstorm", "Snowstorm"),
    ("Space weather event", "Space weather event"),
    ("High Seas/Rogue waves etc.", "High Seas/Rogue waves etc."),
    ("Storm surge/Coastal flood", "Storm surge/Coastal flood"),
    ("Thunderstorms/Squall lines", "Thunderstorms/Squall lines"),
    ("Tornado", "Tornado"),
    ("Tropical cyclone", "Tropical cyclone"),
    ("Tsunami", "Tsunami"),
    ("Volcanic ash", "Volcanic ash"),
    ("Wild land fire/Forest fire", "Wild land fire/Forest fire"),
    ("Wind", "Wind"),
)
